@@ -22,6 +22,19 @@
  *
  */
 
+/**
+ * SECTION:hildon-file-handling-note
+ * @short_description: Displaying the notification when a move 
+ * operation is in progress. 
+ * @see_also: #HildonFileHandlingNote
+ * 
+ * This is the notification displayed when a move operation is in
+ * progress.  The notification uses a progress bar to indicate the
+ * progress of the operation. For operation containing multiple items, a
+ * separe progress bar is shown for each item. The notification has a
+ * single button, which allows users to stop the move operation.
+ */
+
 #include "hildon-note.h"
 #include "hildon-file-handling-note.h"
 #include <stdio.h>
@@ -41,7 +54,8 @@
 #define OPENING_TYPE 2
 #define SAVING_TYPE 3
 
-#define _(String) dgettext(PACKAGE, String)
+/*#define _(String) dgettext(PACKAGE, String)*/
+#define _(String) dgettext("hildon-fm", String) /* FIXME: this file should be moved to hildon-fm */
 
 #define HILDON_FILE_HANDLING_NOTE_GET_PRIVATE(obj)\
         (G_TYPE_INSTANCE_GET_PRIVATE ((obj), \
@@ -54,7 +68,6 @@ struct _HildonFileHandlingNotePrivate {
     guint note_type;
 };
 
-#ifndef HILDON_DISABLE_DEPRECATED
 
 static HildonNote *parent_class;
 
@@ -124,12 +137,13 @@ static void hildon_file_handling_note_finalize(GObject * obj_self)
 /**
  * hildon_file_handling_note_set_counter_and_name:
  * @note: the #HildonFileHandlingNote widget
- * @current: Current item
- * @maximum: Maximum value for counter
- * @name: Filename
+ * @current: progress, current item being processed
+ * @maximum: maximum value for counter (number of items)
+ * @name: filename
  *
  * This function sets current counter value, maximum
  * counter value and filename for dialog 
+ *
  * DEPRECATED: use hildon-note instead of hildon-file-handling-note.
  */
 void hildon_file_handling_note_set_counter_and_name(HildonFileHandlingNote
@@ -191,9 +205,9 @@ void hildon_file_handling_note_set_counter_and_name(HildonFileHandlingNote
 /**
  * hildon_file_handling_note_set_name:
  * @note: the @HildonFileHandlingNote widget
- * @name: Filename
+ * @name: filename
  *
- * This function sets filename for dialog
+ * This function sets the filename for dialog
  * DEPRECATED: use hildon-note instead of hildon-file-handling-note.
  */
 void hildon_file_handling_note_set_name(HildonFileHandlingNote * note,
@@ -242,7 +256,7 @@ void hildon_file_handling_note_set_fraction(HildonFileHandlingNote * note,
  * This function creates new dialog
  * which is "moving" type.
  *
- * Return value: a new #HildonFileHandlingNote.
+ * Returns: a new #HildonFileHandlingNote
  * DEPRECATED: use hildon-note instead of hildon-file-handling-note.
  */
 GtkWidget *hildon_file_handling_note_new_moving(GtkWindow * parent)
@@ -274,7 +288,7 @@ GtkWidget *hildon_file_handling_note_new_moving(GtkWindow * parent)
  * This function creates new dialog
  * which is "deleting" type.
  *
- * Return value: a new #HildonFileHandlingNote.
+ * Returns: a new #HildonFileHandlingNote
  * DEPRECATED: use hildon-note instead of hildon-file-handling-note.
  */
 GtkWidget *hildon_file_handling_note_new_deleting(GtkWindow * parent)
@@ -306,7 +320,7 @@ GtkWidget *hildon_file_handling_note_new_deleting(GtkWindow * parent)
  * This function creates new dialog
  * which is "opening" type
  *
- * Return value: a new #HildonFileHandlingNote.
+ * Returns: a new #HildonFileHandlingNote
  * DEPRECATED: use hildon-note instead of hildon-file-handling-note.
  */
 GtkWidget *hildon_file_handling_note_new_opening(GtkWindow * parent)
@@ -338,7 +352,7 @@ GtkWidget *hildon_file_handling_note_new_opening(GtkWindow * parent)
  * This function creates new dialog
  * which is "saving" type.
  *
- * Return value: a new #HildonFileHandlingNote.
+ * Returns: a new #HildonFileHandlingNote
  * DEPRECATED: use hildon-note instead of hildon-file-handling-note.
  */
 GtkWidget *hildon_file_handling_note_new_saving(GtkWindow * parent)
@@ -363,4 +377,3 @@ GtkWidget *hildon_file_handling_note_new_saving(GtkWindow * parent)
     return GTK_WIDGET(file_note);
 }
 
-#endif /* HILDON_DISABLE_DEPRECATED */
