@@ -22,6 +22,15 @@
  *
  */
 
+/**
+ * SECTION:hildon-font-selection-dialog
+ * @short_description: A widget used to allow users to select a font 
+ * with certain properties
+ *
+ * Font selection can be made using this widget. Users can select font name, 
+ * size, style, etc. Users can also preview text in the selected font.
+ */
+ 
 #include <stdlib.h>
 #include <string.h>
 
@@ -50,10 +59,9 @@
 #define _(String) dgettext(PACKAGE, String)
 
 #define SUPERSCRIPT_RISE 3333
-#define SUBSCRIPT_LOW -3333
-#define ON_BIT 0x01
+#define SUBSCRIPT_LOW   -3333
+#define ON_BIT  0x01
 #define OFF_BIT 0x02
-#define REFERENCE_LINE "Reference: " /*localized string?*/
 
 /*
  * These are what we use as the standard font sizes, for the size list.
@@ -87,7 +95,8 @@ enum
   PROP_STRIKETHROUGH,
   PROP_STRIKETHROUGH_SET,
   PROP_POSITION,
-  PROP_POSITION_SET
+  PROP_POSITION_SET,
+  PROP_PREVIEW_TEXT
 };
 
 typedef struct
@@ -149,9 +158,9 @@ typedef struct
 
 static gboolean
               hildon_font_selection_dialog_preview_key_press
-	                                     (GtkWidget * widget,
-					      GdkEventKey * event,
-					      gpointer data);
+                                            (GtkWidget * widget,
+                                             GdkEventKey * event,
+                                             gpointer unused);
 
 /*Some tools from gtk_font_selection*/
 static int    cmp_families                   (const void *a, const void *b);
@@ -195,7 +204,7 @@ static void   hildon_font_selection_dialog_construct_notebook
 					     
 static void   color_modified_cb              (HildonColorButton *button,
 					      GParamSpec *pspec,
-					      gpointer data);
+					      gpointer fsd_priv);
 
 static void   check_tags                     (gpointer data,
 					      gpointer user_data);
@@ -227,7 +236,7 @@ static void   add_preview_text_attr          (PangoAttrList *list,
 					      guint len);
 
 static void   toggle_clicked                 (GtkButton *button, 
-					      gpointer data);
+					      gpointer unused);
 	
 					     
 					     
@@ -281,7 +290,7 @@ hildon_font_selection_dialog_get_property (GObject      *object,
 	g_value_set_string(value, 
 			   pango_font_family_get_name(priv->families[i]));
       else
-	g_value_set_string(value, "Nokia Sans");
+	g_value_set_string(value, "Sans");
       break;
       
     case PROP_FAMILY_SET:
@@ -385,6 +394,12 @@ hildon_font_selection_dialog_get_property (GObject      *object,
 	g_value_set_boolean(value, FALSE);
       break;
     
+    case PROP_PREVIEW_TEXT:
+	g_value_set_string(value,
+		hildon_font_selection_dialog_get_preview_text(
+		    HILDON_FONT_SELECTION_DIALOG(object)));
+      break;
+    
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -544,6 +559,12 @@ hildon_font_selection_dialog_set_property (GObject         *object,
 	gtk_combo_box_set_active(GTK_COMBO_BOX(priv->cbx_positioning), -1);
       break;
 
+    case PROP_PREVIEW_TEXT:
+      hildon_font_selection_dialog_set_preview_text(
+	      HILDON_FONT_SELECTION_DIALOG(object),
+	      g_value_get_string(value));
+      break;
+    
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -562,10 +583,11 @@ hildon_font_selection_dialog_class_init(HildonFontSelectionDialogClass *
   gobject_class->get_property = hildon_font_selection_dialog_get_property;
   gobject_class->set_property = hildon_font_selection_dialog_set_property;
 
+  /* Install property to the class */
   g_object_class_install_property(gobject_class, PROP_FAMILY,
 				  g_param_spec_string("family",
 				  "Font family", "String defines"
-				  " the font family", "Nokia Sans",
+				  " the font family", "Sans",
 				  G_PARAM_READWRITE));
   
   g_object_class_install_property(gobject_class, PROP_FAMILY_SET,
@@ -672,6 +694,15 @@ hildon_font_selection_dialog_class_init(HildonFontSelectionDialogClass *
 				  "Whether the position"
 				  " is inconsistent", FALSE,
 				  G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+  
+  g_object_class_install_property(gobject_class, PROP_PREVIEW_TEXT,
+				  g_param_spec_string("preview-text",
+				  "Preview Text", 
+				  "the text in preview dialog, which does" 
+				  "not include the reference text",
+				  "",
+				  G_PARAM_READWRITE));
+  
 
   g_type_class_add_private(klass,
 			   sizeof(struct _HildonFontSelectionDialogPrivate));
@@ -738,7 +769,7 @@ hildon_font_selection_dialog_construct_notebook (HildonFontSelectionDialog
   group =
     GTK_SIZE_GROUP(gtk_size_group_new(GTK_SIZE_GROUP_HORIZONTAL));
   
-  /*Tab one*/
+  /* Build the first page of the GtkNotebook: font style */
   priv->cbx_font_type = gtk_combo_box_new_text();
   hildon_font_selection_dialog_show_available_fonts(fontsel);
   caption_control = hildon_caption_new(group,
@@ -768,19 +799,15 @@ hildon_font_selection_dialog_construct_notebook (HildonFontSelectionDialog
   gtk_box_pack_start(GTK_BOX(font_color_box),
 		     priv->font_color_button, FALSE, FALSE, 0);
   
-  /*dummy widget for packing purpose only*/
-  gtk_box_pack_start(GTK_BOX(font_color_box), gtk_label_new(""),
-		     TRUE, TRUE, 0);
-  
   caption_control =
-    hildon_caption_new(group, _("ecdg_fi_font_color_selector"),
+    hildon_caption_new(group, _("ecdg_fi_font_colour_selector"),
 		       font_color_box,
 		       NULL, HILDON_CAPTION_OPTIONAL);
   
   gtk_box_pack_start(GTK_BOX(vbox_tab[0]), caption_control,
 		     FALSE, FALSE, 0);
 
-  /*Tab two*/
+  /* Build the second page of the GtkNotebook: font formatting */ 
   priv->chk_bold = gtk_check_button_new();
   caption_control = hildon_caption_new(group,
 				       _("ecdg_fi_font_bold"),
@@ -812,7 +839,7 @@ hildon_font_selection_dialog_construct_notebook (HildonFontSelectionDialog
   g_signal_connect(G_OBJECT(priv->chk_underline), "clicked", 
 		   G_CALLBACK(toggle_clicked), NULL);
 
-  /*Tab three*/
+  /* Build the third page of the GtkNotebook: other font properties */
   priv->chk_strikethrough = gtk_check_button_new();
   caption_control =
     hildon_caption_new(group, _("ecdg_fi_font_strikethrough"),
@@ -847,10 +874,12 @@ hildon_font_selection_dialog_construct_notebook (HildonFontSelectionDialog
 }
 
 static void 
-color_modified_cb(HildonColorButton *button, GParamSpec *pspec, gpointer data)
+color_modified_cb(HildonColorButton *button, 
+                  GParamSpec *pspec, 
+                  gpointer fsd_priv)
 {
   HildonFontSelectionDialogPrivate *priv = 
-    (HildonFontSelectionDialogPrivate *) data;
+          (HildonFontSelectionDialogPrivate *) fsd_priv;
 
   priv->color_set = TRUE;
 }
@@ -861,7 +890,7 @@ hildon_font_selection_dialog_finalize(GObject * object)
   HildonFontSelectionDialogPrivate *priv;
   HildonFontSelectionDialog *fontsel;
 
-  g_return_if_fail(HILDON_IS_FONT_SELECTION_DIALOG(object));
+  g_assert(HILDON_IS_FONT_SELECTION_DIALOG(object));
   fontsel = HILDON_FONT_SELECTION_DIALOG(object);
 
   priv = HILDON_FONT_SELECTION_DIALOG_GET_PRIVATE(fontsel);
@@ -884,15 +913,17 @@ cmp_families(const void *a, const void *b)
   return g_utf8_collate(a_name, b_name);
 }
 
+/* Exits the preview dialog with GTK_RESPONSE_CANCEL if Esc key
+ * was pressed */
 static gboolean
-hildon_font_selection_dialog_preview_key_press(GtkWidget * widget,
-					       GdkEventKey * event,
-					       gpointer data)
+hildon_font_selection_dialog_preview_key_press(GtkWidget   * widget,
+                                               GdkEventKey * event,
+                                               gpointer      unused)
 {
-  g_return_val_if_fail(widget, FALSE);
-  g_return_val_if_fail(event, FALSE);
-
-  if (event->keyval == GDK_Escape) 
+  g_assert(widget);
+  g_assert(event);
+  
+  if (event->keyval == GDK_Escape)
     {
       gtk_dialog_response(GTK_DIALOG(widget), GTK_RESPONSE_CANCEL);
       return TRUE;
@@ -1051,23 +1082,28 @@ hildon_font_selection_dialog_show_preview(HildonFontSelectionDialog *
 				GTK_RESPONSE_ACCEPT,
 				NULL);
 
-  str = g_strconcat(REFERENCE_LINE, priv->preview_text, 0);
+  str = g_strconcat(_("ecdg_fi_preview_font_preview_reference"),
+                    priv->preview_text, 0);
+
   preview_label = gtk_label_new(str);
+  gtk_label_set_line_wrap(GTK_LABEL(preview_label), TRUE);
+
   g_free(str);
   str = NULL;
 
   gtk_container_add(GTK_CONTAINER(GTK_DIALOG(preview_dialog)->vbox),
 		    preview_label);
 
+  
   /* set keypress handler (ESC hardkey) */
   g_signal_connect(G_OBJECT(preview_dialog), "key-press-event",
-		   G_CALLBACK
-		   (hildon_font_selection_dialog_preview_key_press),
-		   NULL);
-
+                  G_CALLBACK(hildon_font_selection_dialog_preview_key_press),
+                  NULL);
+  
+  
   /*Set the font*/
   list = hildon_font_selection_dialog_create_attrlist(fontsel, 
-				strlen(REFERENCE_LINE),
+				strlen(_("ecdg_fi_preview_font_preview_reference")),
 				strlen(priv->preview_text));
 
   g_object_get(G_OBJECT(fontsel), "family", &str, "family-set",
@@ -1077,7 +1113,7 @@ hildon_font_selection_dialog_show_preview(HildonFontSelectionDialog *
   if(family_set)
     {
       attr = pango_attr_family_new(str);
-      add_preview_text_attr(list, attr, 0, strlen(REFERENCE_LINE));
+      add_preview_text_attr(list, attr, 0, strlen(_("ecdg_fi_preview_font_preview_reference")));
     }
   g_free(str);
   
@@ -1085,7 +1121,7 @@ hildon_font_selection_dialog_show_preview(HildonFontSelectionDialog *
   if(size_set)
     {
       attr = pango_attr_size_new(size * PANGO_SCALE);
-      add_preview_text_attr(list, attr, 0, strlen(REFERENCE_LINE));
+      add_preview_text_attr(list, attr, 0, strlen(_("ecdg_fi_preview_font_preview_reference")));
     }
   
   gtk_label_set_attributes(GTK_LABEL(preview_label), list);
@@ -1099,6 +1135,37 @@ hildon_font_selection_dialog_show_preview(HildonFontSelectionDialog *
   gtk_widget_destroy(preview_dialog);
 }
 
+
+static gboolean is_internal_font(const gchar * name){
+  return strcmp(name, "DeviceSymbols") == 0
+      || strcmp(name, "Nokia Smiley" ) == 0
+      || strcmp(name, "Nokia Sans"   ) == 0
+      || strcmp(name, "Nokia Sans Cn") == 0;
+}
+
+static void filter_out_internal_fonts(PangoFontFamily **families, int *n_families){
+  int i;
+  int n; /* counts valid fonts */
+  const gchar * name = NULL;
+
+  for(i = 0, n = 0; i < *n_families; i++){
+
+    name = pango_font_family_get_name(families[i]);
+        
+    if(!is_internal_font(name)){
+
+      if(i!=n){ /* there are filtered out families */
+	families[n] = families[i]; /* shift the current family */
+      }
+
+      n++; /* count one more valid */
+    }
+  }/* foreach font family */
+
+  *n_families = n;  
+}
+
+
 static void
 hildon_font_selection_dialog_show_available_fonts(HildonFontSelectionDialog 
 						  *fontsel)
@@ -1113,6 +1180,8 @@ hildon_font_selection_dialog_show_available_fonts(HildonFontSelectionDialog
 			      (GTK_WIDGET(fontsel)), &priv->families,
 			      &priv->n_families);
 
+  filter_out_internal_fonts(priv->families, &priv->n_families);
+
   qsort(priv->families, priv->n_families, sizeof(PangoFontFamily *),
 	cmp_families);
 
@@ -1161,6 +1230,7 @@ hildon_font_selection_dialog_show_available_sizes
     }
 }
 
+/* WARNING: This function is called only from deprecated API */
 static
 void check_tags(gpointer data, gpointer user_data)
 {
@@ -1187,7 +1257,8 @@ void check_tags(gpointer data, gpointer user_data)
 	       "rise", &p_rise, "rise-set", & r_s,
 	       NULL);
   
-  /*settings*/
+  /* Check that the given values are valid. 
+   * If not, set the combobox row indicator to 'inconsistent' */
   if(ff_s)
     {
       gint new_f = -1;
@@ -1277,6 +1348,7 @@ void check_tags(gpointer data, gpointer user_data)
     }
 }
 
+/* WARNING: This function is called only from deprecated API */
 static
 void check_attrs(gpointer data, gpointer user_data)
 {
@@ -1292,6 +1364,8 @@ void check_attrs(gpointer data, gpointer user_data)
   gint size, weight, style, underline, strikethrough, rise;
   gint new_f = -1, new_size = -1, new_rise = -1;
 
+  /* Check that the given values are valid.
+   * If not, set the combobox row indicator to 'inconsistent' */
   switch(attr->klass->type)
     {
     case PANGO_ATTR_FAMILY:
@@ -1394,6 +1468,7 @@ void check_attrs(gpointer data, gpointer user_data)
   pango_attribute_destroy(attr);
 }
 
+/* WARNING: This function is called only from deprecated API */
 static void
 settings_init(HildonFontSelectionDialogSettings *settings,
 	      HildonFontSelectionDialog  *fsd)
@@ -1410,6 +1485,7 @@ settings_init(HildonFontSelectionDialogSettings *settings,
   settings->position = -1;
 }
 
+/* WARNING: This function is called only from deprecated API */
 static void
 bit_mask_toggle(gint mask, GtkToggleButton *button,
 		GObject *object, const gchar *prop,
@@ -1433,6 +1509,7 @@ bit_mask_toggle(gint mask, GtkToggleButton *button,
   g_object_notify(object, prop_set);
 }
 
+/* WARNING: This function is called only from deprecated API */
 static void
 combo_active(gint active, GtkComboBox *box, 
 	     GObject *object, const gchar *prop, const gchar *prop_set)
@@ -1452,6 +1529,7 @@ combo_active(gint active, GtkComboBox *box,
   g_object_notify(object, prop_set);
 }
 
+/* WARNING: This function is called only from deprecated API */
 static void
 settings_apply(HildonFontSelectionDialogSettings *settings)
 {
@@ -1520,7 +1598,7 @@ settings_destroy(HildonFontSelectionDialogSettings *settings)
 }
 
 static void
-toggle_clicked(GtkButton *button, gpointer data)
+toggle_clicked(GtkButton *button, gpointer unused)
 {
   GtkToggleButton *t_b = GTK_TOGGLE_BUTTON(button);
 
@@ -1538,13 +1616,13 @@ toggle_clicked(GtkButton *button, gpointer data)
 
 /**
  * hildon_font_selection_dialog_new:
- * @parent: the parent window.
- * @title: the title of font selection dialog.
+ * @parent: the parent window
+ * @title: the title of font selection dialog
  *
  * If NULL is passed for title, then default title
  * "Font" will be used.
  *
- * Return value: a new #HildonFontSelectionDialog.
+ * Returns: a new #HildonFontSelectionDialog
  */
 GtkWidget *
 hildon_font_selection_dialog_new(GtkWindow * parent,
@@ -1566,12 +1644,12 @@ hildon_font_selection_dialog_new(GtkWindow * parent,
 
 /**
  * hildon_font_selection_dialog_get_preview_text:
- * @fsd: the font selection dialog.
+ * @fsd: the font selection dialog
  *
  * Gets the text in preview dialog, which does not include the 
  * reference text. The returned string must be freed by the user.
  *
- * Returns: a string pointer.
+ * Returns: a string pointer
  */
 gchar *
 hildon_font_selection_dialog_get_preview_text(HildonFontSelectionDialog * fsd)
@@ -1585,8 +1663,8 @@ hildon_font_selection_dialog_get_preview_text(HildonFontSelectionDialog * fsd)
 
 /**
  * hildon_font_selection_dialog_set_preview_text:
- * @fsd: the font selection dialog.
- * @text: the text to be set to the preview dialog.
+ * @fsd: the font selection dialog
+ * @text: the text to be displayed in the preview dialog
  *
  * The default preview text is
  * "The quick brown fox jumped over the lazy dogs"
@@ -1595,30 +1673,32 @@ void
 hildon_font_selection_dialog_set_preview_text(HildonFontSelectionDialog *
 					      fsd, const gchar * text)
 {
-  if (HILDON_IS_FONT_SELECTION_DIALOG(fsd)) ;
-    {
-      HildonFontSelectionDialogPrivate *priv =
-	HILDON_FONT_SELECTION_DIALOG_GET_PRIVATE(fsd);
-      g_free(priv->preview_text);
-      priv->preview_text = g_strdup(text);
-    }
+   HildonFontSelectionDialogPrivate *priv = NULL;
+   
+   g_return_if_fail(HILDON_IS_FONT_SELECTION_DIALOG(fsd));
+   g_return_if_fail(text);
+  
+   priv = HILDON_FONT_SELECTION_DIALOG_GET_PRIVATE(fsd);
+   
+   g_free(priv->preview_text);
+   priv->preview_text = g_strdup(text);
+   g_object_notify (G_OBJECT (fsd), "preview-text");
 }
 
 /**
  * hildon_font_selection_dialog_get_text_tag:
- * @fsd: the font selection dialog.
+ * @fsd: the font selection dialog
  *
  * Get the #GtkTextTag for selections. This function
- * is deprecated function. The best way to use
+ * is deprecated. The best way to use
  * the text tags is to reuse them as much as possible.
- * The recommended way is to get the properties of font
- * selection dialog on GTK_RESPONSE_OK, according to
- * these property use the tags that you have pre-created.
+ * The recommended way is to get the properties of the font
+ * selection dialog on GTK_RESPONSE_OK, and according to
+ * these properties use the tags that you have pre-created.
  * 
  * Returns: a #GtkTextTag having corresponding properties
- * set. 
+ * set 
  */ 
-#ifndef HILDON_DISABLE_DEPRECATED
 GtkTextTag * 
 hildon_font_selection_dialog_get_text_tag (HildonFontSelectionDialog *fsd)
 {
@@ -1742,21 +1822,18 @@ hildon_font_selection_dialog_get_text_tag (HildonFontSelectionDialog *fsd)
   
   return tag;
 }
-#endif
 
 /** 
  * hildon_font_selection_dialog_set_buffer:
- * @fsd: the font selection dialog.
+ * @fsd: the font selection dialog
  * @buffer: a #GtkTextBuffer containing the text to which the selections will 
  * be applied. Applying is responsibility of application.
  *
- * This is deprecated function. GtkTextBuffer is not enough
+ * This is deprecated. GtkTextBuffer is not enough
  * to get the attributes of currently selected text. Please 
  * inspect the attributes yourself, and set the properties of
  * font selection dialog to reflect your inspection.
- * 
  */
-#ifndef HILDON_DISABLE_DEPRECATED
 void 
 hildon_font_selection_dialog_set_buffer (HildonFontSelectionDialog *fsd,
 					 GtkTextBuffer *buffer)
@@ -1769,7 +1846,9 @@ hildon_font_selection_dialog_set_buffer (HildonFontSelectionDialog *fsd,
   settings_init(&settings, fsd);
   
   iter = begin;
-  if(gtk_text_iter_compare(&iter, &end) == 0)/*if no selection*/
+
+  /* Keep original settings if the selection includes nothing */ 
+  if(gtk_text_iter_compare(&iter, &end) == 0)
     {
       GSList *slist;
       
@@ -1778,6 +1857,7 @@ hildon_font_selection_dialog_set_buffer (HildonFontSelectionDialog *fsd,
       g_slist_free(slist);
     }
 
+  /* Apply the user settings to the selected text */
   while(gtk_text_iter_compare(&iter, &end) < 0)
     {
       GSList *slist;
@@ -1793,18 +1873,16 @@ hildon_font_selection_dialog_set_buffer (HildonFontSelectionDialog *fsd,
   settings_apply(&settings);
   settings_destroy(&settings);
 }
-#endif
 
 /**
  * hildon_font_selection_dialog_get_font:
- * @fsd: the font selection dialog.
+ * @fsd: the font selection dialog
  *
- * This is a deprecated function, @PangoAttrList needs
+ * This is deprecated. @PangoAttrList needs
  * starting index, and end index on construction.
  *
- * Return value: pointer to @PangoAttrList.
+ * Returns: pointer to @PangoAttrList
  */
-#ifndef HILDON_DISABLE_DEPRECATED
 PangoAttrList
 *hildon_font_selection_dialog_get_font(HildonFontSelectionDialog * fsd)
 {
@@ -1819,18 +1897,16 @@ PangoAttrList
   return hildon_font_selection_dialog_create_attrlist(fsd, 
 				0, strlen(priv->preview_text));
 }
-#endif
 
 /**
  * hildon_font_selection_dialog_set_font:
- * @fsd: the font selection dialog.
- * @list: the pango attribute list.
+ * @fsd: the font selection dialog
+ * @list: the pango attribute list
  *
- * This is a deprecated function.
+ * This is a deprecated.
  * 
  * Sets the font to the dialog.
  */
-#ifndef HILDON_DISABLE_DEPRECATED
 void 
 hildon_font_selection_dialog_set_font(HildonFontSelectionDialog * fsd,
 				      PangoAttrList * list)
@@ -1859,4 +1935,3 @@ hildon_font_selection_dialog_set_font(HildonFontSelectionDialog * fsd,
   settings_apply(&settings);
   settings_destroy(&settings);
 }
-#endif
